==> aws-cdk.aws-cloud9-1.138.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_cloud9_IEc2Environment(p) {
}
function _aws_cdk_aws_cloud9_CloneRepository(p) {
}
function _aws_cdk_aws_cloud9_Ec2EnvironmentProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.clonedRepositories))
        _aws_cdk_aws_cloud9_CloneRepository(p.clonedRepositories);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_cloud9_CfnEnvironmentEC2Props(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_cloud9_Ec2Environment(p) {
}
function _aws_cdk_aws_cloud9_CfnEnvironmentEC2(p) {
}
function _aws_cdk_aws_cloud9_CfnEnvironmentEC2_RepositoryProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_cloud9_IEc2Environment, _aws_cdk_aws_cloud9_CloneRepository, _aws_cdk_aws_cloud9_Ec2EnvironmentProps, _aws_cdk_aws_cloud9_CfnEnvironmentEC2Props, _aws_cdk_aws_cloud9_Ec2Environment, _aws_cdk_aws_cloud9_CfnEnvironmentEC2, _aws_cdk_aws_cloud9_CfnEnvironmentEC2_RepositoryProperty };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-cloud9-1.142.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_cloud9_IEc2Environment(p) {
}
function _aws_cdk_aws_cloud9_CloneRepository(p) {
}
function _aws_cdk_aws_cloud9_CfnEnvironmentEC2Props(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_cloud9_Ec2EnvironmentProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.clonedRepositories))
        _aws_cdk_aws_cloud9_CloneRepository(p.clonedRepositories);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_cloud9_Ec2Environment(p) {
}
function _aws_cdk_aws_cloud9_CfnEnvironmentEC2(p) {
}
function _aws_cdk_aws_cloud9_CfnEnvironmentEC2_RepositoryProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_cloud9_IEc2Environment, _aws_cdk_aws_cloud9_CloneRepository, _aws_cdk_aws_cloud9_CfnEnvironmentEC2Props, _aws_cdk_aws_cloud9_Ec2EnvironmentProps, _aws_cdk_aws_cloud9_Ec2Environment, _aws_cdk_aws_cloud9_CfnEnvironmentEC2, _aws_cdk_aws_cloud9_CfnEnvironmentEC2_RepositoryProperty };
module.exports.DeprecationError = DeprecationError;
